==> vtigercrm-5.2.1p2.tgz: modules/ProjectMilestone/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array(
	 
	'LBL_MODULE_NAME'=>'Hitos',
  	'LBL_MODULE_TITLE'=>'Hitos',
	'LBL_NEW_OPERATION'=>'Nuevo Hito',
    'LBL_MILESTONES'=>'Hitos',
    'LBL_MILESTONE'=>'Hito',
    'Project Milestone ID'=>'ID Hito', 
	'ProjectMilestone' => 'Nombre Hito',
    'projectmilestones' => 'Hitos',
    'SINGLE_ProjectMilestone' => 'Hito',
    'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_MILESTONE_INFORMATION' => 'Información Hito',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
    'Assigned To' => 'Asignado a',
    'Milestone Date' => 'Fecha hito',
    'Milestone' => 'Hito',
    'Type'=>'Tipo',
    //'linktoproject'=>'Link To',
    'Related Project' => 'Proyecto relacionado',
    'Related To' => 'Relacionado con',
	'projectid' => 'Relacionado con',
  	'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'description' => 'Descripción',
    'Description' => 'Descripción',
    //added for related lists 
    'Project Milestone Name' => 'Nombre Hito',
	'Project Milestone No' => 'Nº Hito',

);

?>

==> vtigercrm-5.3.0p0.tgz: modules/ProjectMilestone/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array(
	 
	'LBL_MODULE_NAME'=>'Hitos',
  	'LBL_MODULE_TITLE'=>'Hitos',
	'LBL_NEW_OPERATION'=>'Nuevo Hito',
    'LBL_MILESTONES'=>'Hitos',
    'LBL_MILESTONE'=>'Hito',
    'Project Milestone ID'=>'ID Hito', 
	'ProjectMilestone' => 'Hitos',
    'projectmilestones' => 'Hitos',
    'SINGLE_ProjectMilestone' => 'Hito',
    'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
    'LBL_PROJECT_MILESTONE_INFORMATION' => 'Información Hito',
    'LBL_DESCRIPTION_INFORMATION' => 'Descripción',
    'description' => 'Descripción',
    'Assigned To' => 'Asignado a',
    'Milestone' => 'Hito',
    'Type'=>'Tipo',
    //'linktoproject'=>'Link To',
    'Related Project' => 'Proyecto relacionado',
    'Related To' => 'Relacionado con',
	'projectid' => 'Relacionado con',
  	'administrative' => 'administrativo',
    'operative' => 'operativo',
    'other' => 'otro',
    '--none--' => '--ninguno--',
    'Created Time' => 'Fecha Creación',
    'Modified Time' => 'Fecha Modificación',
    'Description' => 'Descripción',
    //added for related lists 
    'Project Milestone Name' => 'Nombre Hito',
	'Project Milestone No' => 'Nº Hito',
    'Milestone Date'=>'Fecha Hito',

);

?>
